@@ -39,3 +39,20 @@ def plan():
             ],
         }
     )
+
+
+def bake_plan():
+    return Schema(
+        {
+            Optional("common"): dict,
+            Required("version"): 1,
+            Optional("name"): str,
+            Optional("description"): str,
+            Required("jobs"): [
+                Any(
+                    {Optional("name"): str, Required("bake"): dict},
+                    {Optional("name"): str, Required("bakes"): list},
+                )
+            ],
+        }
+    )
